aboutsummaryrefslogtreecommitdiff
path: root/include/sound/wss.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/sound/wss.h')
-rw-r--r--include/sound/wss.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/include/sound/wss.h b/include/sound/wss.h
index 3b53973f96a..1e0dc77f0d2 100644
--- a/include/sound/wss.h
+++ b/include/sound/wss.h
@@ -77,8 +77,10 @@ struct snd_wss {
unsigned short mode; /* see to WSS_MODE_XXXX */
unsigned short hardware; /* see to WSS_HW_XXXX */
unsigned short hwshare; /* shared resources */
- unsigned short single_dma:1, /* forced single DMA mode (GUS 16-bit daughter board) or dma1 == dma2 */
- ebus_flag:1; /* SPARC: EBUS present */
+ unsigned short single_dma:1, /* forced single DMA mode (GUS 16-bit */
+ /* daughter board) or dma1 == dma2 */
+ ebus_flag:1, /* SPARC: EBUS present */
+ thinkpad_flag:1; /* Thinkpad CS4248 needs extra help */
struct snd_card *card;
struct snd_pcm *pcm;